==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/request/WorkbookApplicationRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.guavamini.Preconditions;
import com.github.davidmoten.odata.client.ActionRequestNoReturn;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.Map;

import odata.msgraph.client.beta.entity.WorkbookApplication;
import odata.msgraph.client.beta.schema.SchemaInfo;

@JsonIgnoreType
public class WorkbookApplicationRequest extends EntityRequest<WorkbookApplication> {

    public WorkbookApplicationRequest(ContextPath contextPath) {
        super(WorkbookApplication.class, contextPath, SchemaInfo.INSTANCE);
    }

    @Action(name = "calculate")
    @JsonIgnore
    public ActionRequestNoReturn calculate(String calculationType) {
        Preconditions.checkNotNull(calculationType, "calculationType cannot be null");
        Map<String, TypedObject> _parameters = ParameterMap
            .put("calculationType", "Edm.String", Checks.checkIsAscii(calculationType))
            .build();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.calculate"), _parameters);
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/request/WorkbookApplicationRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.guavamini.Preconditions;
import com.github.davidmoten.odata.client.ActionRequestNoReturn;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.entity.WorkbookApplication;

@JsonIgnoreType
public class WorkbookApplicationRequest extends EntityRequest<WorkbookApplication> {

    public WorkbookApplicationRequest(ContextPath contextPath, Optional<Object> value) {
        super(WorkbookApplication.class, contextPath, value, false);
    }

    @Action(name = "calculate")
    @JsonIgnore
    public ActionRequestNoReturn calculate(String calculationType) {
        Preconditions.checkNotNull(calculationType, "calculationType cannot be null");
        Map<String, TypedObject> _parameters = ParameterMap
            .put("calculationType", "Edm.String", Checks.checkIsAscii(calculationType))
            .build();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.calculate"), _parameters);
    }

}
